/*
 * Convert X-Y-Z coordinate information in '<prefix>%c%c%c' format into NID
 */
#include <basil_mysql.h>
#include <torus_coord.h>

int main(int ac, char **av)
{
	/*
	 * XXX FIXME: the following conditions could be better separated
	 *            using query variables:
	 *            - nid does not exist for coordinate -> DOWN
	 *            - processor_status <> 'up'          -> DOWN
	 *            - processor_type   <> 'compute'     -> DOWN
	 *            - alloc_mode       <> 'batch'       -> DOWN
	 */
	const char query[] =	"SELECT processor_id "
				"FROM  processor "
				"WHERE x_coord = ? "
				"AND   y_coord = ? "
				"AND   z_coord = ? "
				"AND processor_type   = 'compute' "
				"AND processor_status = 'up' "
				"AND alloc_mode       = 'batch'";
	MYSQL_BIND	bind_parm[TORUS_MAX_DIM];
	struct torus_coord tc;
	enum query_columns {
			COL_NID,
			COLUMN_COUNT	/* sentinel */
	};
	MYSQL_BIND	bind_cols[COLUMN_COUNT];
	unsigned int	node_id;
	my_bool		is_null[COLUMN_COUNT];
	my_bool		error[COLUMN_COUNT];
	MYSQL		*handle;
	MYSQL_STMT	*stmt;
	int		rc = -1, i;

	handle = cray_connect_sdb();
	if (handle == NULL)
		errx(1, "can not connect to XTAdmin database on the SDB");

	memset(bind_parm, 0, sizeof(bind_parm));
	for (i = 0; i < TORUS_MAX_DIM; i ++)
		bind_parm[i].buffer_type = MYSQL_TYPE_LONG;
	bind_parm[0].buffer = (char *)&tc.x;
	bind_parm[1].buffer = (char *)&tc.y;
	bind_parm[2].buffer = (char *)&tc.z;

	memset(bind_cols, 0, sizeof(bind_cols));
	for (i = 0; i < COLUMN_COUNT; i ++) {
		bind_cols[i].is_null = &is_null[i];
		bind_cols[i].error   = &error[i];
	}
	bind_cols[COL_NID].buffer_type	= MYSQL_TYPE_LONG;
	bind_parm[COL_NID].is_unsigned	= true;
	bind_cols[COL_NID].buffer	= (char *)&node_id;

	stmt = prepare_stmt(handle, query, bind_parm, TORUS_MAX_DIM,
					   bind_cols, COLUMN_COUNT);
	if (stmt == NULL)
		goto err;

	for (i = 0; i < ac - 1; i++) {
		char *p = *++av;

		if (sscanf(p, "%d %d %d", &tc.x, &tc.y, &tc.z) == 3) {
			/* Space-separated X/Y/Z digits */
		} else if (str2toruscoord(p, &tc)) {
			/* With suffix */
		} else {
			warnx("'%s' neither in 'X Y Z' nor in '<alpha>*xyz' format", *av);
			continue;
		}

		if (exec_stmt(stmt, query, bind_cols, COLUMN_COUNT) < 0)
			goto err_close;

		if (i == 0)
			printf("  X   Y   Z    NID\n");

		printf("%3d %3d %3d", tc.x, tc.y, tc.z);

		if (mysql_stmt_fetch(stmt) == 0)
			printf(" %6u\n", node_id);
		else
			printf("      ?\n");
	}

	rc = 0;
err_close:
	if (mysql_stmt_close(stmt))
		warnx("error closing statement: %s",
			mysql_stmt_error(stmt));
err:
	mysql_close(handle);

	return rc ? EXIT_FAILURE : EXIT_SUCCESS;
}
